#
# spec file for package csync
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           csync
BuildRequires:  check
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libsmbclient-devel
%if 0%{?suse_version}
BuildRequires:  libiniparser-devel
BuildRequires:  liblog4c-devel
BuildRequires:  libneon-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libssh-devel
BuildRequires:  sqlite3-devel
%endif
%if 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  libiniparser-devel
BuildRequires:  libssh2-devel
BuildRequires:  log4cpp-devel
BuildRequires:  neon-devel
BuildRequires:  openssl-devel
BuildRequires:  sqlite-devel
%endif
%if 0%{?fedora_version}
BuildRequires:  iniparser-devel
BuildRequires:  libssh-devel
BuildRequires:  log4cpp-devel
BuildRequires:  neon-devel
BuildRequires:  openssl-devel
BuildRequires:  sqlite-devel
%endif
%if 0%{?mdk_version}
BuildRequires:  iniparser-devel
BuildRequires:  libssh-devel
BuildRequires:  log4c-devel
BuildRequires:  neon-devel
BuildRequires:  sqlite-devel
%endif

Version:        0.50.8
Release:        39.1
Summary:        A user level bidirectional client only file synchronizer
License:        GPL-2.0+
Group:          Productivity/Networking/Other
Url:            http://www.csync.org/
Source0:        %{name}-%{version}.tar.bz2
Source1:        baselibs.conf
%if 0%{?sles_version} || 0%{?centos_version} || 0%{?rhel_version}
Patch0:         remove_signal.dif
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
csync is an implementation of a file synchronizer which provides the
feature of roaming home directories for Linux clients. csync makes use
of libsmbclient in Samba/Windows environments.

%package -n libcsync0
Summary:        A user level bidirectional client only file synchronizer
Group:          System/Libraries
%if 0%{?suse_version} > 1030
Recommends:     libcsync-plugin-smb

%if !0%{?sles_version}
Recommends:     libcsync-plugin-sftp
%endif
%endif

%description -n libcsync0
csync is an implementation of a file synchronizer which provides the
feature of roaming home directories for Linux clients. csync makes use
of libsmbclient in Samba/Windows environments.

%package -n libcsync-plugin-smb
Summary:        SMB plugin for csync
Group:          System/Libraries
Requires:       libcsync0 = %{version}

%description -n libcsync-plugin-smb
This plug-in allows applications using csync to synchronize with a
Samba or Windows server.

%if 0%{?fedora_version} || 0%{?suse_version} || 0%{?mdk_version}
%if !0%{?sles_version}

%package -n libcsync-plugin-sftp
Summary:        A user level bidirectional client only file synchronizer
Group:          Productivity/Networking/Other
Requires:       libcsync0 = %{version}

%description -n libcsync-plugin-sftp
csync is an implementation of a file synchronizer which provides the
feature of roaming home directories for clients. csync makes use
of libsmbclient in Samba/Windows environments.
%endif
%else
# disabled due to old libssh on centos, rhel and sles
%endif

%package -n libcsync-plugin-owncloud
Summary:        A user level bidirectional client only file synchronizer
Group:          Productivity/Networking/Other
Requires:       libcsync0 = %{version}

%description -n libcsync-plugin-owncloud
csync is an implementation of a file synchronizer which provides the
feature of roaming home directories for Linux clients. csync makes use
of libneon to access ownCloud. 

%package -n libcsync-devel
Summary:        Development files for csync
Group:          Development/Libraries/C and C++
Requires:       libcsync0 = %{version}

%description -n libcsync-devel
The libcsync-devel package contains the static libraries and header
files needed for development with csync.

%package -n libcsync-devel-doc
Summary:        Developer documentation for csync
Group:          Development/Languages/C and C++

%description -n libcsync-devel-doc
The libcsync-devel-doc package provides documentation for csync
development.

%package -n libcsync-doc
Summary:        User documentation for csync
Group:          Development/Languages/C and C++

%description -n libcsync-doc
The libcsync-doc package provides user documentation for csync.

%prep
%setup -q
%if 0%{?sles_version} || 0%{?rhel_version} || 0%{?centos_version}
%patch0 -p 1
%endif

%build
if test ! -e "build"; then
  %{__mkdir} build
fi
pushd build
cmake \
  -DLOG_TO_CALLBACK=ON \
  -DCMAKE_C_FLAGS:STRING="%{optflags}" \
  -DCMAKE_CXX_FLAGS:STRING="%{optflags}" \
  -DCMAKE_SKIP_RPATH=ON \
  -DCMAKE_BUILD_TYPE=RelWithDebInfo \
  -DCMAKE_INSTALL_PREFIX=%{_prefix} \
  -DSYSCONF_INSTALL_DIR=%{_sysconfdir} \
%if %{_lib} == lib64
  -DLIB_SUFFIX=64 \
%endif
  %{_builddir}/%{name}-%{version}
%__make %{?jobs:-j%jobs} VERBOSE=1
%__make doc
popd build

%install
pushd build
%if 0%{?suse_version}
%makeinstall
%else
make DESTDIR=%{buildroot} install
%endif
popd build

%post -n libcsync0
/sbin/ldconfig

%postun -n libcsync0
/sbin/ldconfig

%clean
%__rm -rf %{buildroot}

%files
%defattr(-,root,root)
%{_bindir}/csync
%{_mandir}/man?/csync.*

%files -n libcsync0
%defattr(-,root,root)
%doc AUTHORS COPYING INSTALL README
%dir %{_sysconfdir}/csync
%config(noreplace) %{_sysconfdir}/csync/csync.conf
%config(noreplace) %{_sysconfdir}/csync/csync_exclude.conf
%config(noreplace) %{_sysconfdir}/csync/csync_log.conf
%{_libdir}/libcsync.so.*
%dir %{_libdir}/csync-0

%files -n libcsync-plugin-smb
%defattr(-,root,root)
%{_libdir}/csync-0/csync_smb.so

%if 0%{?suse_version} || 0%{?fedora_version} || 0%{?mdk_version}
%if !0%{?sles_version}

%files -n libcsync-plugin-sftp
%defattr(-,root,root)
%{_libdir}/csync-0/csync_sftp.so
%endif
%else
#disabled on rhel, sles and centos due to old libssh version
%endif

%files -n libcsync-plugin-owncloud
%defattr(-,root,root)
%{_libdir}/csync-0/csync_owncloud.so

%files -n libcsync-devel
%defattr(-,root,root)
%{_includedir}/csync
%{_libdir}/libcsync.so

%files -n libcsync-devel-doc
%defattr(-,root,root)
%doc build/doc/html

%files -n libcsync-doc
%defattr(-,root,root)
%{_datadir}/doc/csync

%changelog
* Fri Aug 10 2012 freitag@owncloud.com
- updated to version 0.50.8 (released 2012-08-10)
  * Inode equivalent support for Win32 platforms to support rename
  * ownCloud supports propagates renames from local to webdav MOVE
  * ownCloud module works with proxy, settings from mirall.
  * improved CMake modules (openSSL)
  * Fixed namespace for lastmodified propset.
  * Added cmocka based tests for ownCloud module.
  * Added a config_test.h config header file.
  * Fix link handling: Ignore symlinks.
  * Modules can now report their capabilities to csync core.
  * A lot of minor fixes and improvements.
* Fri Jun 22 2012 freitag@owncloud.com
- update to version 0.50.7 (released 2012-06-19)
  * Added ability to log to a callback, ie. let the app
    catch the log output
  * Added push to remote without pushing to temp file first.
  * Fixed file copy function to use wide character (win32).
  * Fixed loading of statedb if user has special char (win32).
* Wed May 16 2012 freitag@owncloud.com
- update to final 0.50.6
  * Directories with 'strange' characters broke sync. (oC bug #613)
  * Special characters in Windows did not sync correctly. (oC bug #478)
  * Make neon redirecting
  * Switch logging off on Apple to not fill the syslog. (oC bug #622)
* Fri May 11 2012 freitag@owncloud.com
- update to beta of 0.50.6, next release.
* Fri Apr 20 2012 msrex@owncloud.com
- reformat debian packaging files
* Thu Apr 19 2012 msrex@owncloud.com
- clean-up convoluted requires
* Thu Apr 19 2012 msrex@owncloud.com
- also disable sftp module on SLES
* Wed Apr 18 2012 msrex@owncloud.com
- re-enable sftp-module on fedora
* Wed Apr 18 2012 msrex@owncloud.com
- disable sftp-module on RHEL and CentOS
* Wed Apr 18 2012 msrex@owncloud.com
- fix dependencies for RHEL / CentOS
* Wed Apr 18 2012 msrex@owncloud.com
- changes to debian packaging
* Wed Apr 18 2012 freitag@opensuse.org
- version 0.50.5 (released 2012-04-18)
  required for owncloud client 1.0.1
  * removed argp lib dependency
  * simplified and fixed CMake files
  * MacOS porting efforts
  * more granular error reports, thread save
* Mon Apr  2 2012 freitag@opensuse.org
- Update to upstream version 0.50.4 with more fine tunes and fixes.
* Mon Apr  2 2012 freitag@opensuse.org
- Disable sftp for SLES as the package is too old.
* Mon Mar 26 2012 freitag@opensuse.org
- Update to internal beta version 0.50.3 with more bugfixes.
* Tue Mar 13 2012 freitag@opensuse.org
- Update to internal beta version 0.50.2 with more bugfixes.
* Fri Mar  2 2012 freitag@opensuse.org
- Update to internal beta version 0.50.1
* Wed Feb 22 2012 freitag@opensuse.org
- Update to upstream beta version 0.49.9:
  * Added owncloud module.
  * Added backup reconciler.
  * Fixed serveral bugs.
* Tue Feb 16 2010 anschneider@exsuse.de
- Build always with libssh support.
* Mon Feb 15 2010 anschneider@exsuse.de
- Update to version 0.44.0.
  * Migrated sftp module to libssh 0.4.
  * Added more cache entries to the default config.
  * Added missing requirements.
  * Fixed build warnings.
  * Fixed some memory leaks using sftp attributes.
  * Some code cleanups.
* Sun Jan 31 2010 jengelh@medozas.de
- Package baselibs.conf
* Mon May 25 2009 anschneider@exsuse.de
- Update to version 0.43.0.
  * Added SFTP support with libssh 0.3.
  * Added possibility to pass userdata to the auth function.
  * Added a better version function.
  * Fixed CMake build.
  * Fixed CMake find modules.
  * Fixed some flaws in cstd functions.
  * Documented all public functions.
* Fri Apr 17 2009 anschneider@exsuse.de
- Fix Fedora build.
- Change the way how to set CFLAGS.
* Thu Feb 26 2009 anschneider@suse.de
- Update to version 0.42.0
  * Small fix in the userguide.
* Fri Jan 23 2009 anschneider@suse.de
- Update to version 0.42.0 rc3
  * Added checks for unix extensions.
  * Added more documentation to the userguide.
  * Fixed loading of plugins.
  * Fixed call for deletion functions.
  * Normalize the path to <hostname>/<path> for the statedb filename.
  * More change name of client options to be more descriptive.
- Add recommends for the plugins.
* Thu Jan  8 2009 anschneider@suse.de
- Fix loading of plugins.
- Add requires to the plugins.
* Thu Jan  8 2009 anschneider@suse.de
- Update to version 0.42.0 rc2
  * Reduced syscalls
  * Fixed a bug in the state database
  * Fixed libsmbclient support
  * Completed userguide
* Fri Dec  5 2008 anschneider@suse.de
- Update to version 0.42.0 rc1
  libcsync:
  * Reduced calls of syscall functions.
  * Added own function to create a temporary filename.
  * Fixed libsmbclient 3.0.x support.
* Wed Sep 10 2008 anschneider@suse.de
- Created a subpackage for each plugin and for the user guide
- Update to version 0.42.0 beta1
  libcsync:
  * Added a sftp module using libssh
  * Added user guide (just a start)
  * Added testcase for update detection
  * Added a function to parse an uri to cstdlib
  * Updated the manpage
  * Fixed some segfaults in cstdlib
  * Fixed some memory leaks
  csync:
  * Improved the auth callback
* Thu Jul  3 2008 anschneider@suse.de
- Set the right group for the different packages
* Wed Jul  2 2008 anschneider@suse.de
- Update to version 0.42.0 alpha4
  libcsync:
  * Added the possibility to run csync completely without a journal
  * Improved chmod calls during propagation. Most of the time we use the
    default mode and don't need to call chmod.
  * Improved the exclude list handling in the file tree walker. This
    increased the speed of the update detection.
  * Fixed csync on PPC
  * Fixed serveral small bugs
  csync:
  * Added commandline option to run csync completely without a journal
* Fri Jun 27 2008 anschneider@suse.de
- Fixed csync on PPC
* Wed Jun 25 2008 anschneider@suse.de
- Update to version 0.42.0 alpha3
  libcsync:
  * Added a tree merger to write a complete journal
  * Added support to run csync without a journal
  * Fixed kerberos support in csync_smb module
  * Fixed closing of files after the copy
  * Fixed update detection to detect special files (fifo, pipes,
    char devices, ..)
  * Fixed O_NOATIME flag on open() if we don't have the permission
  csync:
  * Add a variable to run csync completely without a journal
* Tue Jun 17 2008 anschneider@suse.de
- Fix update detection for special files (fifo, char device, ..)
- Fix propagation for files the user doesn't own
* Mon Jun 16 2008 anschneider@suse.de
- Update to version 0.41.92 (0.42.0 alpha2)
  libcsync:
  * Peformance improvements
  * Add more directories to the standard exclude file
  * Bugfixes
* Wed Jun  4 2008 anschneider@suse.de
- Build for redhat based distributions
* Mon Jun  2 2008 anschneider@suse.de
- Update to version 0.41.91 (0.42.0 alpha1)
* Mon May  5 2008 anschneider@suse.de
- Initial verison 0.41.90
